@@ -5,7 +5,7 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-11-23'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.025'; # VERSION
+our $VERSION = '0.026'; # VERSION
 
 our $schema = ["dirname" => {
     summary => 'Directory name, defaults to only subdirectory in current directory (if there is one)',
@@ -15,6 +15,11 @@ This is like the `dirname` schema but with a default value of "only subdirectory
 in the current directory". That is, if the current directory has a single
 subdirectory and nothing else.
 
+Difference with `dirname::default_only_subdir_not_file_in_subdir` schema: the
+other schema ignores plain files. Thus, if a directory only contains `file1` and
+`subdir1`, then that other schema will return `subdir1` but this schema will not
+return a default value.
+
 Note: be careful when using this schema for actions that are destructive,
 because a user can perform those actions without giving an argument (e.g. in a
 `delete-files-in` script). It is safer to use this schema when performing a
@@ -39,7 +44,7 @@ Sah::Schema::dirname::default_only_subdir_in_curdir - Directory name, defaults t
 
 =head1 VERSION
 
-This document describes version 0.025 of Sah::Schema::dirname::default_only_subdir_in_curdir (from Perl distribution Sah-Schemas-Path), released on 2023-11-23.
+This document describes version 0.026 of Sah::Schema::dirname::default_only_subdir_in_curdir (from Perl distribution Sah-Schemas-Path), released on 2023-11-23.
 
 =head1 SYNOPSIS
 
@@ -162,6 +167,11 @@ This is like the C<dirname> schema but with a default value of "only subdirector
 in the current directory". That is, if the current directory has a single
 subdirectory and nothing else.
 
+Difference with C<dirname::default_only_subdir_not_file_in_subdir> schema: the
+other schema ignores plain files. Thus, if a directory only contains C<file1> and
+C<subdir1>, then that other schema will return C<subdir1> but this schema will not
+return a default value.
+
 Note: be careful when using this schema for actions that are destructive,
 because a user can perform those actions without giving an argument (e.g. in a
 C<delete-files-in> script). It is safer to use this schema when performing a
