@@ -5,7 +5,7 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-11-23'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.025'; # VERSION
+our $VERSION = '0.026'; # VERSION
 
 1;
 # ABSTRACT: Schemas related to filesystem path
@@ -22,7 +22,7 @@ Sah::Schemas::Path - Schemas related to filesystem path
 
 =head1 VERSION
 
-This document describes version 0.025 of Sah::Schemas::Path (from Perl distribution Sah-Schemas-Path), released on 2023-11-23.
+This document describes version 0.026 of Sah::Schemas::Path (from Perl distribution Sah-Schemas-Path), released on 2023-11-23.
 
 =head1 DESCRIPTION
 
@@ -102,6 +102,30 @@ This is like the C<dirname> schema but with a default value of "only subdirector
 in the current directory". That is, if the current directory has a single
 subdirectory and nothing else.
 
+Difference with C<dirname::default_only_subdir_not_file_in_subdir> schema: the
+other schema ignores plain files. Thus, if a directory only contains C<file1> and
+C<subdir1>, then that other schema will return C<subdir1> but this schema will not
+return a default value.
+
+Note: be careful when using this schema for actions that are destructive,
+because a user can perform those actions without giving an argument (e.g. in a
+C<delete-files-in> script). It is safer to use this schema when performing a
+non=destructive action (e.g. C<ls>) and/or operate in dry-run mode by default.
+
+
+=item * L<dirname::default_only_subdir_not_file_in_curdir|Sah::Schema::dirname::default_only_subdir_not_file_in_curdir>
+
+Directory name, defaults to only subdirectory in current directory (if there is one) (files ignored).
+
+This is like the C<dirname> schema but with a default value of "only subdirectory
+in the current directory". That is, if the current directory has a single
+subdirectory and nothing else (plain files are ignored).
+
+Difference with C<dirname::default_only_subdir_in_subdir> schema: the other
+schema does not ignore plain files. Thus, if a directory only contains C<file1>
+and C<subdir1>, then that other schema will not return C<subdir1> but this schema
+will.
+
 Note: be careful when using this schema for actions that are destructive,
 because a user can perform those actions without giving an argument (e.g. in a
 C<delete-files-in> script). It is safer to use this schema when performing a
